@@ -1,7 +1,7 @@
 from odsclient.core import ODSClient, ODSException, NoODSAPIKeyFoundError, InsufficientRightsForODSResourceError, \
-    ENV_ODS_APIKEY, KR_DEFAULT_USERNAME
+    ENV_ODS_APIKEY, KR_DEFAULT_USERNAME, CacheEntry
 from odsclient.shortcuts import get_whole_dataset, get_whole_dataframe, store_apikey_in_keyring, \
-    get_apikey_from_keyring, remove_apikey_from_keyring, get_apikey
+    get_apikey_from_keyring, remove_apikey_from_keyring, get_apikey, clean_cache, get_cached_dataset_entry
 
 __all__ = [
     # submodules
@@ -10,5 +10,5 @@ __all__ = [
     'ODSClient', 'ODSException', 'NoODSAPIKeyFoundError', 'InsufficientRightsForODSResourceError',
     'ENV_ODS_APIKEY', 'KR_DEFAULT_USERNAME',
     'get_whole_dataset', 'get_whole_dataframe', 'store_apikey_in_keyring', 'get_apikey_from_keyring',
-    'remove_apikey_from_keyring', 'get_apikey'
+    'remove_apikey_from_keyring', 'get_apikey', 'clean_cache', 'get_cached_dataset_entry', 'CacheEntry'
 ]
